/* @file dhcp6_nic.c
 *
 * Network Interface Configurator for the DHCPv6 IPv6 DHCP client library.
 *
 */
/*
 * Copyright (C) 2006  Red Hat, Inc. All rights reserved.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions of
 * the GNU General Public License v.2.  This program is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY expressed or
 * implied, including the implied warranties of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.  You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
 * USA. Any Red Hat trademarks that are incorporated in the source code or
 * documentation are not subject to the GNU General Public License and may
 * only be used or replicated with the express permission of Red Hat, Inc.
 *
 * Red Hat Author(s): Jason Vas Dias
 *                    David Cantrell
 */
#include <libdhcp.h>
#include <dhcp6_lease.h>
#include <nic.h>
#include <stdarg.h>

/**
 * @addtogroup  DHCPv6
 * @{
 */
typedef
struct dhcp6_nic_s
{
    NLH_t          nh;
    NIC_t          nic;
    IPaddr_list_t  address_list;
    IProute_list_t route_list;
    IPaddr_list_t  dns_list;
    char          *search_list;
    char          *host_name;
    DHCPv6_lease  *lease;
    char          *name;
} DHCPv6_nic;

extern
DHCPv6_nic *do_dhcpv6( LIBDHCP_Control *, NLH_t nh, char *if_name );

extern
DHCPv6_nic *dhcp6_nic_from_lease( LIBDHCP_Control *ctl, NLH_t nh, DHCPv6_lease *lease, NIC_t nic);

extern
int dhcp6_process_lease( LIBDHCP_Control *ctl, DHCPv6_nic *nic );

extern
NIC_Res_t dhcpv6_nic( DHCPv6_nic* );

extern
int dhcp6_nic_callback
(   LIBDHCP_Control *control,
    DHCP_State state, 
    void *arg
);

void dhcpv6_nic_free( DHCPv6_nic* );

/**@}*/
