#include <sys/types.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <pump.h>

void logger(void *arg, int priority, char *fmt, va_list va)
{
    libdhcp_stderr_logger(0, priority, fmt, va);
}

int main( int argc, char **argv, char **envp)
{
    struct pumpNetIntf ifx;

    memset(&ifx, '\0', sizeof(ifx));

    strcpy(&(ifx.device[0]),"eth0");
    
    char *s = 
	pumpDhcpClassRun
	(
	    &ifx,
	    0L, 0L, 0, 0, 
	    10, 
	    logger,
	    LOG_DEBUG
	),
	buf[64];
    
    if( s != 0L )
    {
	printf("%s\n",s);
	return 1;
    }

    if( ifx.set & PUMP_INTFINFO_HAS_IP )
	printf("ip: %s\n",
	       ip_text_addr(&(ifx.ip),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_IPV4_IP )
	printf("ipv4: %s\n",
	       ip_text_addr(&(ifx.ipv4),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_IPV6_IP )
	printf("ipv6: %s\n",
	       ip_text_addr(&(ifx.ipv6),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_IPV6_PREFIX )
	printf("ipv6_prefixlen: %d\n",
	       ifx.ipv6_prefixlen
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_NETMASK )
	printf("netmask: %s\n",
	       ip_text_addr(&(ifx.netmask),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_NETWORK )
	printf("network: %s\n",
	       ip_text_addr(&(ifx.network),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_BROADCAST )
	printf("broadcast: %s\n",
	       ip_text_addr(&(ifx.broadcast),buf,64)
	      );

    if( ifx.set & PUMP_NETINFO_HAS_GATEWAY )
	printf("gateway: %s\n",
	       ip_text_addr(&(ifx.gateway),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_NEXTSERVER )
	printf("nextServer: %s\n",
	       ip_text_addr(&(ifx.nextServer),buf,64)
	      );

    if( ifx.set & PUMP_INTFINFO_HAS_MTU )
	printf("mtu: %d\n",
	       ifx.mtu
	      );
        
    if( ifx.set & PUMP_NETINFO_HAS_DNS )
    {
	if( ifx.domain )
	    printf("domain: %s\n",
		   ifx.domain
		  );
	if( ifx.numDns )
	{
	    int i;
	    for(i=0; i < ifx.numDns; i++)
		printf("nameserver: %s\n",
		       ip_text_addr(&(ifx.dnsServers[i]),buf,64)
		      );
	}
    }
    
    if( ifx.set & PUMP_NETINFO_HAS_HOSTNAME )       
    {
	printf("hostname: %s\n",
	       ifx.hostname
	       );
    }

    if( ifx.set & PUMP_INTFINFO_HAS_BOOTFILE )       
    {
	printf("bootFile: %s\n",
	       ifx.bootFile
	       );
    }

    if( (s = pumpSetupInterface( &ifx )) != 0 )
    {
	printf("pumpSetupInterface failed: %s\n", s);
	return 1;
    }
	
    return 0;
}

